@@ -198,26 +198,40 @@ class Task():
         self.cwd = cwd
         self.steps = []
         self.script = script
+        self.standalone = standalone
+
         self._data = {}  # task-specific data
-        log_time = datetime.strftime(datetime.now(), '%Y%m%d-%H%M%S')
-        self.log_dir = sys.argv[1] if not standalone else os.path.join(cwd, 'logs', name, log_time)
-        self.execution_logfile = os.path.join(self.log_dir, "execution_log.txt")
-        self.zmq_logfile = os.path.join(self.log_dir, "zmq_log.txt")
+        self.log_time = datetime.strftime(datetime.now(), '%Y%m%d-%H%M%S')
+        self.log_dir = self._init_log_dir()
+        self.execution_logfile = sys.argv[1] if not standalone else os.path.join(self.log_dir, "execution_log.txt")
+        print(self.execution_logfile)
+        self.zmq_logfile = sys.argv[1] if not standalone else os.path.join(self.log_dir, "zmq_log.txt")
         self.zmq_client_socket = self._get_zmq_client_socket()
         self.last_box_location = None
         self.error = False
-        self.standalone = standalone
         # read execution and zmq logfile names from command line args if not run as standalone
 
         self._print_title()
 
     def _get_zmq_client_socket(self):
         """Establishes ZMQ connection with engine manager process and returns Socket"""
-        self._log_zmq("Connecting to ZMQ client socket.")
-        context = zmq.Context()
-        socket = context.socket(zmq.REQ)
-        socket.connect(f"tcp://localhost:{ZMQ_PORT}")
-        return socket
+        if self.standalone:
+            return None
+        else:
+            self._log_zmq("Connecting to ZMQ client socket.")
+            context = zmq.Context()
+            socket = context.socket(zmq.REQ)
+            socket.connect(f"tcp://localhost:{ZMQ_PORT}")
+            return socket
+
+    def _init_log_dir(self):
+        if not self.standalone:
+            return sys.argv[1]
+        else:
+            path =  os.path.join(self.cwd, 'logs', self.name, self.log_time)
+            if not os.path.exists(path):
+                os.makedirs(path)
+            return path
 
     def add_step(self, step):
         """Add a step to the current list of steps.
